#[allow(clippy::too_many_lines)]
#[test]
fn test_() {
    use super::*;
    const TEST_CASES: [(i64, &str); 1912] = [
        (21_4748_3647, "二一億四七百四八万三六百四七"),
        (21_4748_3647, "二十一億四七百四八万三六百四七"),
        (87_6543, "八十七万六五百四三"),
        (87_6543, "八七万六五百四三"),
        (1234_5678, "一二百三四万五六百七八"),
        (12345, "万二三百四五"),
        (121, "百二一"),
        (122, "百二二"),
        (123, "百二三"),
        (124, "百二四"),
        (125, "百二五"),
        (126, "百二六"),
        (127, "百二七"),
        (128, "百二八"),
        (129, "百二九"),
        (131, "百三一"),
        (132, "百三二"),
        (133, "百三三"),
        (134, "百三四"),
        (135, "百三五"),
        (136, "百三六"),
        (137, "百三七"),
        (138, "百三八"),
        (139, "百三九"),
        (141, "百四一"),
        (142, "百四二"),
        (143, "百四三"),
        (144, "百四四"),
        (145, "百四五"),
        (146, "百四六"),
        (147, "百四七"),
        (148, "百四八"),
        (149, "百四九"),
        (151, "百五一"),
        (152, "百五二"),
        (153, "百五三"),
        (154, "百五四"),
        (155, "百五五"),
        (156, "百五六"),
        (157, "百五七"),
        (158, "百五八"),
        (159, "百五九"),
        (161, "百六一"),
        (162, "百六二"),
        (163, "百六三"),
        (164, "百六四"),
        (165, "百六五"),
        (166, "百六六"),
        (167, "百六七"),
        (168, "百六八"),
        (169, "百六九"),
        (171, "百七一"),
        (172, "百七二"),
        (173, "百七三"),
        (174, "百七四"),
        (175, "百七五"),
        (176, "百七六"),
        (177, "百七七"),
        (178, "百七八"),
        (179, "百七九"),
        (181, "百八一"),
        (182, "百八二"),
        (183, "百八三"),
        (184, "百八四"),
        (185, "百八五"),
        (186, "百八六"),
        (187, "百八七"),
        (188, "百八八"),
        (189, "百八九"),
        (191, "百九一"),
        (192, "百九二"),
        (193, "百九三"),
        (194, "百九四"),
        (195, "百九五"),
        (196, "百九六"),
        (197, "百九七"),
        (198, "百九八"),
        (199, "百九九"),
        (1, "一"),
        (2, "二"),
        (3, "三"),
        (4, "四"),
        (5, "五"),
        (6, "六"),
        (7, "七"),
        (8, "八"),
        (9, "九"),
        (10, "十"),
        (11, "十一"),
        (12, "十二"),
        (13, "十三"),
        (14, "十四"),
        (15, "十五"),
        (16, "十六"),
        (17, "十七"),
        (18, "十八"),
        (19, "十九"),
        (20, "二十"),
        (21, "二十一"),
        (22, "二十二"),
        (23, "二十三"),
        (24, "二十四"),
        (25, "二十五"),
        (26, "二十六"),
        (27, "二十七"),
        (28, "二十八"),
        (29, "二十九"),
        (30, "三十"),
        (31, "三十一"),
        (32, "三十二"),
        (33, "三十三"),
        (34, "三十四"),
        (35, "三十五"),
        (36, "三十六"),
        (37, "三十七"),
        (38, "三十八"),
        (39, "三十九"),
        (40, "四十"),
        (41, "四十一"),
        (42, "四十二"),
        (43, "四十三"),
        (44, "四十四"),
        (45, "四十五"),
        (46, "四十六"),
        (47, "四十七"),
        (48, "四十八"),
        (49, "四十九"),
        (50, "五十"),
        (51, "五十一"),
        (52, "五十二"),
        (53, "五十三"),
        (54, "五十四"),
        (55, "五十五"),
        (56, "五十六"),
        (57, "五十七"),
        (58, "五十八"),
        (59, "五十九"),
        (60, "六十"),
        (61, "六十一"),
        (62, "六十二"),
        (63, "六十三"),
        (64, "六十四"),
        (65, "六十五"),
        (66, "六十六"),
        (67, "六十七"),
        (68, "六十八"),
        (69, "六十九"),
        (70, "七十"),
        (71, "七十一"),
        (72, "七十二"),
        (73, "七十三"),
        (74, "七十四"),
        (75, "七十五"),
        (76, "七十六"),
        (77, "七十七"),
        (78, "七十八"),
        (79, "七十九"),
        (80, "八十"),
        (81, "八十一"),
        (82, "八十二"),
        (83, "八十三"),
        (84, "八十四"),
        (85, "八十五"),
        (86, "八十六"),
        (87, "八十七"),
        (88, "八十八"),
        (89, "八十九"),
        (90, "九十"),
        (91, "九十一"),
        (92, "九十二"),
        (93, "九十三"),
        (94, "九十四"),
        (95, "九十五"),
        (96, "九十六"),
        (97, "九十七"),
        (98, "九十八"),
        (99, "九十九"),
        (100, "百"),
        (101, "百一"),
        (102, "百二"),
        (103, "百三"),
        (104, "百四"),
        (105, "百五"),
        (106, "百六"),
        (107, "百七"),
        (108, "百八"),
        (109, "百九"),
        (110, "百十"),
        (111, "百十一"),
        (112, "百十二"),
        (113, "百十三"),
        (114, "百十四"),
        (115, "百十五"),
        (116, "百十六"),
        (117, "百十七"),
        (118, "百十八"),
        (119, "百十九"),
        (120, "百二十"),
        (121, "百二十一"),
        (122, "百二十二"),
        (123, "百二十三"),
        (124, "百二十四"),
        (125, "百二十五"),
        (126, "百二十六"),
        (127, "百二十七"),
        (128, "百二十八"),
        (129, "百二十九"),
        (130, "百三十"),
        (131, "百三十一"),
        (132, "百三十二"),
        (133, "百三十三"),
        (134, "百三十四"),
        (135, "百三十五"),
        (136, "百三十六"),
        (137, "百三十七"),
        (138, "百三十八"),
        (139, "百三十九"),
        (140, "百四十"),
        (141, "百四十一"),
        (142, "百四十二"),
        (143, "百四十三"),
        (144, "百四十四"),
        (145, "百四十五"),
        (146, "百四十六"),
        (147, "百四十七"),
        (148, "百四十八"),
        (149, "百四十九"),
        (150, "百五十"),
        (151, "百五十一"),
        (152, "百五十二"),
        (153, "百五十三"),
        (154, "百五十四"),
        (155, "百五十五"),
        (156, "百五十六"),
        (157, "百五十七"),
        (158, "百五十八"),
        (159, "百五十九"),
        (160, "百六十"),
        (161, "百六十一"),
        (162, "百六十二"),
        (163, "百六十三"),
        (164, "百六十四"),
        (165, "百六十五"),
        (166, "百六十六"),
        (167, "百六十七"),
        (168, "百六十八"),
        (169, "百六十九"),
        (170, "百七十"),
        (171, "百七十一"),
        (172, "百七十二"),
        (173, "百七十三"),
        (174, "百七十四"),
        (175, "百七十五"),
        (176, "百七十六"),
        (177, "百七十七"),
        (178, "百七十八"),
        (179, "百七十九"),
        (180, "百八十"),
        (181, "百八十一"),
        (182, "百八十二"),
        (183, "百八十三"),
        (184, "百八十四"),
        (185, "百八十五"),
        (186, "百八十六"),
        (187, "百八十七"),
        (188, "百八十八"),
        (189, "百八十九"),
        (190, "百九十"),
        (191, "百九十一"),
        (192, "百九十二"),
        (193, "百九十三"),
        (194, "百九十四"),
        (195, "百九十五"),
        (196, "百九十六"),
        (197, "百九十七"),
        (198, "百九十八"),
        (199, "百九十九"),
        (200, "二百"),
        (201, "二百一"),
        (202, "二百二"),
        (203, "二百三"),
        (204, "二百四"),
        (205, "二百五"),
        (206, "二百六"),
        (207, "二百七"),
        (208, "二百八"),
        (209, "二百九"),
        (210, "二百十"),
        (211, "二百十一"),
        (212, "二百十二"),
        (213, "二百十三"),
        (214, "二百十四"),
        (215, "二百十五"),
        (216, "二百十六"),
        (217, "二百十七"),
        (218, "二百十八"),
        (219, "二百十九"),
        (220, "二百二十"),
        (221, "二百二一"),
        (222, "二百二二"),
        (223, "二百二三"),
        (224, "二百二四"),
        (225, "二百二五"),
        (226, "二百二六"),
        (227, "二百二七"),
        (228, "二百二八"),
        (229, "二百二九"),
        (230, "二百三十"),
        (231, "二百三一"),
        (232, "二百三二"),
        (233, "二百三三"),
        (234, "二百三四"),
        (235, "二百三五"),
        (236, "二百三六"),
        (237, "二百三七"),
        (238, "二百三八"),
        (239, "二百三九"),
        (240, "二百四十"),
        (241, "二百四一"),
        (242, "二百四二"),
        (243, "二百四三"),
        (244, "二百四四"),
        (245, "二百四五"),
        (246, "二百四六"),
        (247, "二百四七"),
        (248, "二百四八"),
        (249, "二百四九"),
        (250, "二百五十"),
        (251, "二百五一"),
        (252, "二百五二"),
        (253, "二百五三"),
        (254, "二百五四"),
        (255, "二百五五"),
        (256, "二百五六"),
        (257, "二百五七"),
        (258, "二百五八"),
        (259, "二百五九"),
        (260, "二百六十"),
        (261, "二百六一"),
        (262, "二百六二"),
        (263, "二百六三"),
        (264, "二百六四"),
        (265, "二百六五"),
        (266, "二百六六"),
        (267, "二百六七"),
        (268, "二百六八"),
        (269, "二百六九"),
        (270, "二百七十"),
        (271, "二百七一"),
        (272, "二百七二"),
        (273, "二百七三"),
        (274, "二百七四"),
        (275, "二百七五"),
        (276, "二百七六"),
        (277, "二百七七"),
        (278, "二百七八"),
        (279, "二百七九"),
        (280, "二百八十"),
        (281, "二百八一"),
        (282, "二百八二"),
        (283, "二百八三"),
        (284, "二百八四"),
        (285, "二百八五"),
        (286, "二百八六"),
        (287, "二百八七"),
        (288, "二百八八"),
        (289, "二百八九"),
        (290, "二百九十"),
        (291, "二百九一"),
        (292, "二百九二"),
        (293, "二百九三"),
        (294, "二百九四"),
        (295, "二百九五"),
        (296, "二百九六"),
        (297, "二百九七"),
        (298, "二百九八"),
        (299, "二百九九"),
        (965, "九百六五"),
        (966, "九百六六"),
        (967, "九百六七"),
        (968, "九百六八"),
        (969, "九百六九"),
        (970, "九百七十"),
        (971, "九百七一"),
        (972, "九百七二"),
        (973, "九百七三"),
        (974, "九百七四"),
        (975, "九百七五"),
        (976, "九百七六"),
        (977, "九百七七"),
        (978, "九百七八"),
        (979, "九百七九"),
        (980, "九百八十"),
        (981, "九百八一"),
        (982, "九百八二"),
        (983, "九百八三"),
        (984, "九百八四"),
        (985, "九百八五"),
        (986, "九百八六"),
        (987, "九百八七"),
        (988, "九百八八"),
        (989, "九百八九"),
        (990, "九百九十"),
        (991, "九百九一"),
        (992, "九百九二"),
        (993, "九百九三"),
        (994, "九百九四"),
        (995, "九百九五"),
        (996, "九百九六"),
        (997, "九百九七"),
        (998, "九百九八"),
        (999, "九百九九"),
        (1000, "十百"),
        (1001, "十百一"),
        (1002, "十百二"),
        (1003, "十百三"),
        (1004, "十百四"),
        (1005, "十百五"),
        (1006, "十百六"),
        (1007, "十百七"),
        (1008, "十百八"),
        (1009, "十百九"),
        (1010, "十百十"),
        (1011, "十百十一"),
        (1012, "十百十二"),
        (1013, "十百十三"),
        (1014, "十百十四"),
        (1015, "十百十五"),
        (1016, "十百十六"),
        (1017, "十百十七"),
        (1018, "十百十八"),
        (1019, "十百十九"),
        (1020, "十百二十"),
        (1021, "十百二一"),
        (1022, "十百二二"),
        (1023, "十百二三"),
        (1024, "十百二四"),
        (1025, "十百二五"),
        (1026, "十百二六"),
        (1027, "十百二七"),
        (1028, "十百二八"),
        (1029, "十百二九"),
        (1030, "十百三十"),
        (1031, "十百三一"),
        (1032, "十百三二"),
        (1033, "十百三三"),
        (1034, "十百三四"),
        (1035, "十百三五"),
        (1036, "十百三六"),
        (1037, "十百三七"),
        (1038, "十百三八"),
        (1039, "十百三九"),
        (1040, "十百四十"),
        (1041, "十百四一"),
        (1042, "十百四二"),
        (1043, "十百四三"),
        (1044, "十百四四"),
        (1045, "十百四五"),
        (1046, "十百四六"),
        (1047, "十百四七"),
        (1048, "十百四八"),
        (1049, "十百四九"),
        (1050, "十百五十"),
        (1051, "十百五一"),
        (1052, "十百五二"),
        (1053, "十百五三"),
        (1054, "十百五四"),
        (1055, "十百五五"),
        (1056, "十百五六"),
        (1057, "十百五七"),
        (1058, "十百五八"),
        (1059, "十百五九"),
        (1060, "十百六十"),
        (1061, "十百六一"),
        (1062, "十百六二"),
        (1063, "十百六三"),
        (1064, "十百六四"),
        (1065, "十百六五"),
        (1066, "十百六六"),
        (1067, "十百六七"),
        (1068, "十百六八"),
        (1069, "十百六九"),
        (1070, "十百七十"),
        (1071, "十百七一"),
        (1072, "十百七二"),
        (1073, "十百七三"),
        (1074, "十百七四"),
        (1075, "十百七五"),
        (1076, "十百七六"),
        (1077, "十百七七"),
        (1078, "十百七八"),
        (1079, "十百七九"),
        (1080, "十百八十"),
        (1081, "十百八一"),
        (1082, "十百八二"),
        (1083, "十百八三"),
        (1084, "十百八四"),
        (1085, "十百八五"),
        (1086, "十百八六"),
        (1087, "十百八七"),
        (1088, "十百八八"),
        (1089, "十百八九"),
        (1090, "十百九十"),
        (1091, "十百九一"),
        (1092, "十百九二"),
        (1093, "十百九三"),
        (1094, "十百九四"),
        (1095, "十百九五"),
        (1096, "十百九六"),
        (1097, "十百九七"),
        (1098, "十百九八"),
        (1099, "十百九九"),
        (1100, "十一百"),
        (1101, "十一百一"),
        (1102, "十一百二"),
        (1103, "十一百三"),
        (1104, "十一百四"),
        (1105, "十一百五"),
        (1106, "十一百六"),
        (1107, "十一百七"),
        (1108, "十一百八"),
        (1109, "十一百九"),
        (1110, "十一百十"),
        (1111, "十一百十一"),
        (1112, "十一百十二"),
        (1113, "十一百十三"),
        (1114, "十一百十四"),
        (1115, "十一百十五"),
        (1116, "十一百十六"),
        (1117, "十一百十七"),
        (1118, "十一百十八"),
        (1119, "十一百十九"),
        (1120, "十一百二十"),
        (1121, "十一百二一"),
        (1122, "十一百二二"),
        (1123, "十一百二三"),
        (1124, "十一百二四"),
        (1125, "十一百二五"),
        (1126, "十一百二六"),
        (1127, "十一百二七"),
        (1128, "十一百二八"),
        (1129, "十一百二九"),
        (1130, "十一百三十"),
        (1131, "十一百三一"),
        (1132, "十一百三二"),
        (1133, "十一百三三"),
        (1134, "十一百三四"),
        (1135, "十一百三五"),
        (1136, "十一百三六"),
        (1137, "十一百三七"),
        (1138, "十一百三八"),
        (1139, "十一百三九"),
        (1140, "十一百四十"),
        (1141, "十一百四一"),
        (1142, "十一百四二"),
        (1143, "十一百四三"),
        (1144, "十一百四四"),
        (1145, "十一百四五"),
        (1146, "十一百四六"),
        (1147, "十一百四七"),
        (1148, "十一百四八"),
        (1149, "十一百四九"),
        (1150, "十一百五十"),
        (1151, "十一百五一"),
        (1152, "十一百五二"),
        (1153, "十一百五三"),
        (1154, "十一百五四"),
        (1155, "十一百五五"),
        (1156, "十一百五六"),
        (1157, "十一百五七"),
        (1158, "十一百五八"),
        (1159, "十一百五九"),
        (1160, "十一百六十"),
        (1161, "十一百六一"),
        (1162, "十一百六二"),
        (1163, "十一百六三"),
        (1164, "十一百六四"),
        (1165, "十一百六五"),
        (1166, "十一百六六"),
        (1167, "十一百六七"),
        (1168, "十一百六八"),
        (1169, "十一百六九"),
        (1170, "十一百七十"),
        (1171, "十一百七一"),
        (1172, "十一百七二"),
        (1173, "十一百七三"),
        (1174, "十一百七四"),
        (1175, "十一百七五"),
        (1176, "十一百七六"),
        (1177, "十一百七七"),
        (1178, "十一百七八"),
        (1179, "十一百七九"),
        (1180, "十一百八十"),
        (1181, "十一百八一"),
        (1182, "十一百八二"),
        (1183, "十一百八三"),
        (1184, "十一百八四"),
        (1185, "十一百八五"),
        (1186, "十一百八六"),
        (1187, "十一百八七"),
        (1188, "十一百八八"),
        (1189, "十一百八九"),
        (1190, "十一百九十"),
        (1191, "十一百九一"),
        (1192, "十一百九二"),
        (1193, "十一百九三"),
        (1194, "十一百九四"),
        (1195, "十一百九五"),
        (1196, "十一百九六"),
        (1197, "十一百九七"),
        (1198, "十一百九八"),
        (1199, "十一百九九"),
        (1200, "十二百"),
        (1201, "十二百一"),
        (1202, "十二百二"),
        (1203, "十二百三"),
        (1204, "十二百四"),
        (1205, "十二百五"),
        (1206, "十二百六"),
        (1207, "十二百七"),
        (1208, "十二百八"),
        (1209, "十二百九"),
        (1210, "十二百十"),
        (1211, "十二百十一"),
        (1212, "十二百十二"),
        (1213, "十二百十三"),
        (1214, "十二百十四"),
        (1215, "十二百十五"),
        (1216, "十二百十六"),
        (1217, "十二百十七"),
        (1218, "十二百十八"),
        (1219, "十二百十九"),
        (1220, "十二百二十"),
        (1221, "十二百二一"),
        (1222, "十二百二二"),
        (1223, "十二百二三"),
        (1224, "十二百二四"),
        (1225, "十二百二五"),
        (1226, "十二百二六"),
        (1227, "十二百二七"),
        (1228, "十二百二八"),
        (1229, "十二百二九"),
        (1230, "十二百三十"),
        (1231, "十二百三一"),
        (1232, "十二百三二"),
        (1233, "十二百三三"),
        (1234, "十二百三四"),
        (1235, "十二百三五"),
        (1236, "十二百三六"),
        (1237, "十二百三七"),
        (1238, "十二百三八"),
        (1239, "十二百三九"),
        (1240, "十二百四十"),
        (1241, "十二百四一"),
        (1242, "十二百四二"),
        (1243, "十二百四三"),
        (1244, "十二百四四"),
        (1245, "十二百四五"),
        (1246, "十二百四六"),
        (1247, "十二百四七"),
        (1248, "十二百四八"),
        (1249, "十二百四九"),
        (1250, "十二百五十"),
        (1251, "十二百五一"),
        (1252, "十二百五二"),
        (1253, "十二百五三"),
        (1254, "十二百五四"),
        (1255, "十二百五五"),
        (1256, "十二百五六"),
        (1257, "十二百五七"),
        (1258, "十二百五八"),
        (1259, "十二百五九"),
        (1260, "十二百六十"),
        (1261, "十二百六一"),
        (1262, "十二百六二"),
        (1263, "十二百六三"),
        (1264, "十二百六四"),
        (1265, "十二百六五"),
        (1266, "十二百六六"),
        (1267, "十二百六七"),
        (1268, "十二百六八"),
        (1269, "十二百六九"),
        (1270, "十二百七十"),
        (1271, "十二百七一"),
        (1272, "十二百七二"),
        (1273, "十二百七三"),
        (1274, "十二百七四"),
        (1275, "十二百七五"),
        (1276, "十二百七六"),
        (1277, "十二百七七"),
        (1278, "十二百七八"),
        (1279, "十二百七九"),
        (1280, "十二百八十"),
        (1281, "十二百八一"),
        (1282, "十二百八二"),
        (1283, "十二百八三"),
        (1284, "十二百八四"),
        (1285, "十二百八五"),
        (1286, "十二百八六"),
        (1287, "十二百八七"),
        (1288, "十二百八八"),
        (1289, "十二百八九"),
        (1290, "十二百九十"),
        (1291, "十二百九一"),
        (1292, "十二百九二"),
        (1293, "十二百九三"),
        (1294, "十二百九四"),
        (1295, "十二百九五"),
        (1296, "十二百九六"),
        (1297, "十二百九七"),
        (1298, "十二百九八"),
        (1299, "十二百九九"),
        (1300, "十三百"),
        (1301, "十三百一"),
        (1302, "十三百二"),
        (1303, "十三百三"),
        (1304, "十三百四"),
        (1305, "十三百五"),
        (1306, "十三百六"),
        (1307, "十三百七"),
        (1308, "十三百八"),
        (1309, "十三百九"),
        (1310, "十三百十"),
        (1311, "十三百十一"),
        (1312, "十三百十二"),
        (1313, "十三百十三"),
        (1314, "十三百十四"),
        (1315, "十三百十五"),
        (1316, "十三百十六"),
        (1317, "十三百十七"),
        (1318, "十三百十八"),
        (1319, "十三百十九"),
        (1320, "十三百二十"),
        (1321, "十三百二一"),
        (1322, "十三百二二"),
        (1323, "十三百二三"),
        (1324, "十三百二四"),
        (1325, "十三百二五"),
        (1326, "十三百二六"),
        (1327, "十三百二七"),
        (1328, "十三百二八"),
        (1329, "十三百二九"),
        (1330, "十三百三十"),
        (1331, "十三百三一"),
        (1332, "十三百三二"),
        (1333, "十三百三三"),
        (1334, "十三百三四"),
        (1335, "十三百三五"),
        (1336, "十三百三六"),
        (1337, "十三百三七"),
        (1338, "十三百三八"),
        (1339, "十三百三九"),
        (1340, "十三百四十"),
        (1341, "十三百四一"),
        (1342, "十三百四二"),
        (1343, "十三百四三"),
        (1344, "十三百四四"),
        (1345, "十三百四五"),
        (1346, "十三百四六"),
        (1347, "十三百四七"),
        (1348, "十三百四八"),
        (1349, "十三百四九"),
        (1350, "十三百五十"),
        (1351, "十三百五一"),
        (1352, "十三百五二"),
        (1353, "十三百五三"),
        (1354, "十三百五四"),
        (1355, "十三百五五"),
        (1356, "十三百五六"),
        (1357, "十三百五七"),
        (1358, "十三百五八"),
        (1359, "十三百五九"),
        (1360, "十三百六十"),
        (1361, "十三百六一"),
        (1362, "十三百六二"),
        (1363, "十三百六三"),
        (1364, "十三百六四"),
        (1365, "十三百六五"),
        (1366, "十三百六六"),
        (1367, "十三百六七"),
        (1368, "十三百六八"),
        (1369, "十三百六九"),
        (1370, "十三百七十"),
        (1371, "十三百七一"),
        (1372, "十三百七二"),
        (1373, "十三百七三"),
        (1374, "十三百七四"),
        (1375, "十三百七五"),
        (1376, "十三百七六"),
        (1377, "十三百七七"),
        (1378, "十三百七八"),
        (1379, "十三百七九"),
        (1380, "十三百八十"),
        (1381, "十三百八一"),
        (1382, "十三百八二"),
        (1383, "十三百八三"),
        (1384, "十三百八四"),
        (1385, "十三百八五"),
        (1386, "十三百八六"),
        (1387, "十三百八七"),
        (1388, "十三百八八"),
        (1389, "十三百八九"),
        (1390, "十三百九十"),
        (1391, "十三百九一"),
        (1392, "十三百九二"),
        (1393, "十三百九三"),
        (1394, "十三百九四"),
        (1395, "十三百九五"),
        (1396, "十三百九六"),
        (1397, "十三百九七"),
        (1398, "十三百九八"),
        (1399, "十三百九九"),
        (1400, "十四百"),
        (1401, "十四百一"),
        (1402, "十四百二"),
        (1403, "十四百三"),
        (1404, "十四百四"),
        (1405, "十四百五"),
        (1406, "十四百六"),
        (1407, "十四百七"),
        (1408, "十四百八"),
        (1409, "十四百九"),
        (1410, "十四百十"),
        (1411, "十四百十一"),
        (1412, "十四百十二"),
        (1413, "十四百十三"),
        (1414, "十四百十四"),
        (1415, "十四百十五"),
        (1416, "十四百十六"),
        (1417, "十四百十七"),
        (1418, "十四百十八"),
        (1419, "十四百十九"),
        (1420, "十四百二十"),
        (1421, "十四百二一"),
        (1422, "十四百二二"),
        (1423, "十四百二三"),
        (1424, "十四百二四"),
        (1425, "十四百二五"),
        (1426, "十四百二六"),
        (1427, "十四百二七"),
        (1428, "十四百二八"),
        (1429, "十四百二九"),
        (1430, "十四百三十"),
        (1431, "十四百三一"),
        (1432, "十四百三二"),
        (1433, "十四百三三"),
        (1434, "十四百三四"),
        (1435, "十四百三五"),
        (1436, "十四百三六"),
        (1437, "十四百三七"),
        (1438, "十四百三八"),
        (1439, "十四百三九"),
        (1440, "十四百四十"),
        (1441, "十四百四一"),
        (1442, "十四百四二"),
        (1443, "十四百四三"),
        (1444, "十四百四四"),
        (1445, "十四百四五"),
        (1446, "十四百四六"),
        (1447, "十四百四七"),
        (1448, "十四百四八"),
        (1449, "十四百四九"),
        (1450, "十四百五十"),
        (1451, "十四百五一"),
        (1452, "十四百五二"),
        (1453, "十四百五三"),
        (1454, "十四百五四"),
        (1455, "十四百五五"),
        (1456, "十四百五六"),
        (1457, "十四百五七"),
        (1458, "十四百五八"),
        (1459, "十四百五九"),
        (1460, "十四百六十"),
        (1461, "十四百六一"),
        (1462, "十四百六二"),
        (1463, "十四百六三"),
        (1464, "十四百六四"),
        (1465, "十四百六五"),
        (1466, "十四百六六"),
        (1467, "十四百六七"),
        (1468, "十四百六八"),
        (1469, "十四百六九"),
        (1470, "十四百七十"),
        (1471, "十四百七一"),
        (1472, "十四百七二"),
        (1473, "十四百七三"),
        (1474, "十四百七四"),
        (1475, "十四百七五"),
        (1476, "十四百七六"),
        (1477, "十四百七七"),
        (1478, "十四百七八"),
        (1479, "十四百七九"),
        (1480, "十四百八十"),
        (1481, "十四百八一"),
        (1482, "十四百八二"),
        (1483, "十四百八三"),
        (1484, "十四百八四"),
        (1485, "十四百八五"),
        (1486, "十四百八六"),
        (1487, "十四百八七"),
        (1488, "十四百八八"),
        (1489, "十四百八九"),
        (1490, "十四百九十"),
        (1491, "十四百九一"),
        (1492, "十四百九二"),
        (1493, "十四百九三"),
        (1494, "十四百九四"),
        (1495, "十四百九五"),
        (1496, "十四百九六"),
        (1497, "十四百九七"),
        (1498, "十四百九八"),
        (1499, "十四百九九"),
        (1500, "十五百"),
        (1501, "十五百一"),
        (1502, "十五百二"),
        (1503, "十五百三"),
        (1504, "十五百四"),
        (1505, "十五百五"),
        (1506, "十五百六"),
        (1507, "十五百七"),
        (1508, "十五百八"),
        (1509, "十五百九"),
        (1510, "十五百十"),
        (1511, "十五百十一"),
        (1512, "十五百十二"),
        (1513, "十五百十三"),
        (1514, "十五百十四"),
        (1515, "十五百十五"),
        (1516, "十五百十六"),
        (1517, "十五百十七"),
        (1518, "十五百十八"),
        (1519, "十五百十九"),
        (1520, "十五百二十"),
        (1521, "十五百二一"),
        (1522, "十五百二二"),
        (1523, "十五百二三"),
        (1524, "十五百二四"),
        (1525, "十五百二五"),
        (1526, "十五百二六"),
        (1527, "十五百二七"),
        (1528, "十五百二八"),
        (1529, "十五百二九"),
        (1530, "十五百三十"),
        (1531, "十五百三一"),
        (1532, "十五百三二"),
        (1533, "十五百三三"),
        (1534, "十五百三四"),
        (1535, "十五百三五"),
        (1536, "十五百三六"),
        (1537, "十五百三七"),
        (1538, "十五百三八"),
        (1539, "十五百三九"),
        (1540, "十五百四十"),
        (1541, "十五百四一"),
        (1542, "十五百四二"),
        (1543, "十五百四三"),
        (1544, "十五百四四"),
        (1545, "十五百四五"),
        (1546, "十五百四六"),
        (1547, "十五百四七"),
        (1548, "十五百四八"),
        (1549, "十五百四九"),
        (1550, "十五百五十"),
        (1551, "十五百五一"),
        (1552, "十五百五二"),
        (1553, "十五百五三"),
        (1554, "十五百五四"),
        (1555, "十五百五五"),
        (1556, "十五百五六"),
        (1557, "十五百五七"),
        (1558, "十五百五八"),
        (1559, "十五百五九"),
        (1560, "十五百六十"),
        (1561, "十五百六一"),
        (1562, "十五百六二"),
        (1563, "十五百六三"),
        (1564, "十五百六四"),
        (1565, "十五百六五"),
        (1566, "十五百六六"),
        (1567, "十五百六七"),
        (1568, "十五百六八"),
        (1569, "十五百六九"),
        (1570, "十五百七十"),
        (1571, "十五百七一"),
        (1572, "十五百七二"),
        (1573, "十五百七三"),
        (1574, "十五百七四"),
        (1575, "十五百七五"),
        (1576, "十五百七六"),
        (1577, "十五百七七"),
        (1578, "十五百七八"),
        (1579, "十五百七九"),
        (1580, "十五百八十"),
        (1581, "十五百八一"),
        (1582, "十五百八二"),
        (1583, "十五百八三"),
        (1584, "十五百八四"),
        (1585, "十五百八五"),
        (1586, "十五百八六"),
        (1587, "十五百八七"),
        (1588, "十五百八八"),
        (1589, "十五百八九"),
        (1590, "十五百九十"),
        (1591, "十五百九一"),
        (1592, "十五百九二"),
        (1593, "十五百九三"),
        (1594, "十五百九四"),
        (1595, "十五百九五"),
        (1596, "十五百九六"),
        (1597, "十五百九七"),
        (1598, "十五百九八"),
        (1599, "十五百九九"),
        (1600, "十六百"),
        (1601, "十六百一"),
        (1602, "十六百二"),
        (1603, "十六百三"),
        (1604, "十六百四"),
        (1605, "十六百五"),
        (1606, "十六百六"),
        (1607, "十六百七"),
        (1608, "十六百八"),
        (1609, "十六百九"),
        (1610, "十六百十"),
        (1611, "十六百十一"),
        (1612, "十六百十二"),
        (1613, "十六百十三"),
        (1614, "十六百十四"),
        (1615, "十六百十五"),
        (1616, "十六百十六"),
        (1617, "十六百十七"),
        (1618, "十六百十八"),
        (1619, "十六百十九"),
        (1620, "十六百二十"),
        (1621, "十六百二一"),
        (1622, "十六百二二"),
        (1623, "十六百二三"),
        (1624, "十六百二四"),
        (1625, "十六百二五"),
        (1626, "十六百二六"),
        (1627, "十六百二七"),
        (1628, "十六百二八"),
        (1629, "十六百二九"),
        (1630, "十六百三十"),
        (1631, "十六百三一"),
        (1632, "十六百三二"),
        (1633, "十六百三三"),
        (1634, "十六百三四"),
        (1635, "十六百三五"),
        (1636, "十六百三六"),
        (1637, "十六百三七"),
        (1638, "十六百三八"),
        (1639, "十六百三九"),
        (1640, "十六百四十"),
        (1641, "十六百四一"),
        (1642, "十六百四二"),
        (1643, "十六百四三"),
        (1644, "十六百四四"),
        (1645, "十六百四五"),
        (1646, "十六百四六"),
        (1647, "十六百四七"),
        (1648, "十六百四八"),
        (1649, "十六百四九"),
        (1650, "十六百五十"),
        (1651, "十六百五一"),
        (1652, "十六百五二"),
        (1653, "十六百五三"),
        (1654, "十六百五四"),
        (1655, "十六百五五"),
        (1656, "十六百五六"),
        (1657, "十六百五七"),
        (1658, "十六百五八"),
        (1659, "十六百五九"),
        (1660, "十六百六十"),
        (1661, "十六百六一"),
        (1662, "十六百六二"),
        (1663, "十六百六三"),
        (1664, "十六百六四"),
        (1665, "十六百六五"),
        (1666, "十六百六六"),
        (1667, "十六百六七"),
        (1668, "十六百六八"),
        (1669, "十六百六九"),
        (1670, "十六百七十"),
        (1671, "十六百七一"),
        (1672, "十六百七二"),
        (1673, "十六百七三"),
        (1674, "十六百七四"),
        (1675, "十六百七五"),
        (1676, "十六百七六"),
        (1677, "十六百七七"),
        (1678, "十六百七八"),
        (1679, "十六百七九"),
        (1680, "十六百八十"),
        (1681, "十六百八一"),
        (1682, "十六百八二"),
        (1683, "十六百八三"),
        (1684, "十六百八四"),
        (1685, "十六百八五"),
        (1686, "十六百八六"),
        (1687, "十六百八七"),
        (1688, "十六百八八"),
        (1689, "十六百八九"),
        (1690, "十六百九十"),
        (1691, "十六百九一"),
        (1692, "十六百九二"),
        (1693, "十六百九三"),
        (1694, "十六百九四"),
        (1695, "十六百九五"),
        (1696, "十六百九六"),
        (1697, "十六百九七"),
        (1698, "十六百九八"),
        (1699, "十六百九九"),
        (1700, "十七百"),
        (1701, "十七百一"),
        (1702, "十七百二"),
        (1703, "十七百三"),
        (1704, "十七百四"),
        (1705, "十七百五"),
        (1706, "十七百六"),
        (1707, "十七百七"),
        (1708, "十七百八"),
        (1709, "十七百九"),
        (1710, "十七百十"),
        (1711, "十七百十一"),
        (1712, "十七百十二"),
        (1713, "十七百十三"),
        (1714, "十七百十四"),
        (1715, "十七百十五"),
        (1716, "十七百十六"),
        (1717, "十七百十七"),
        (1718, "十七百十八"),
        (1719, "十七百十九"),
        (1720, "十七百二十"),
        (1721, "十七百二一"),
        (1722, "十七百二二"),
        (1723, "十七百二三"),
        (1724, "十七百二四"),
        (1725, "十七百二五"),
        (1726, "十七百二六"),
        (1727, "十七百二七"),
        (1728, "十七百二八"),
        (1729, "十七百二九"),
        (1730, "十七百三十"),
        (1731, "十七百三一"),
        (1732, "十七百三二"),
        (1733, "十七百三三"),
        (1734, "十七百三四"),
        (1735, "十七百三五"),
        (1736, "十七百三六"),
        (1737, "十七百三七"),
        (1738, "十七百三八"),
        (1739, "十七百三九"),
        (1740, "十七百四十"),
        (1741, "十七百四一"),
        (1742, "十七百四二"),
        (1743, "十七百四三"),
        (1744, "十七百四四"),
        (1745, "十七百四五"),
        (1746, "十七百四六"),
        (1747, "十七百四七"),
        (1748, "十七百四八"),
        (1749, "十七百四九"),
        (1750, "十七百五十"),
        (1751, "十七百五一"),
        (1752, "十七百五二"),
        (1753, "十七百五三"),
        (1754, "十七百五四"),
        (1755, "十七百五五"),
        (1756, "十七百五六"),
        (1757, "十七百五七"),
        (1758, "十七百五八"),
        (1759, "十七百五九"),
        (1760, "十七百六十"),
        (1761, "十七百六一"),
        (1762, "十七百六二"),
        (1763, "十七百六三"),
        (1764, "十七百六四"),
        (1765, "十七百六五"),
        (1766, "十七百六六"),
        (1767, "十七百六七"),
        (1768, "十七百六八"),
        (1769, "十七百六九"),
        (1770, "十七百七十"),
        (1771, "十七百七一"),
        (1772, "十七百七二"),
        (1773, "十七百七三"),
        (1774, "十七百七四"),
        (1775, "十七百七五"),
        (1776, "十七百七六"),
        (1777, "十七百七七"),
        (1778, "十七百七八"),
        (1779, "十七百七九"),
        (1780, "十七百八十"),
        (1781, "十七百八一"),
        (1782, "十七百八二"),
        (1783, "十七百八三"),
        (1784, "十七百八四"),
        (1785, "十七百八五"),
        (1786, "十七百八六"),
        (1787, "十七百八七"),
        (1788, "十七百八八"),
        (1789, "十七百八九"),
        (1790, "十七百九十"),
        (1791, "十七百九一"),
        (1792, "十七百九二"),
        (1793, "十七百九三"),
        (1794, "十七百九四"),
        (1795, "十七百九五"),
        (1796, "十七百九六"),
        (1797, "十七百九七"),
        (1798, "十七百九八"),
        (1799, "十七百九九"),
        (1800, "十八百"),
        (1801, "十八百一"),
        (1802, "十八百二"),
        (1803, "十八百三"),
        (1804, "十八百四"),
        (1805, "十八百五"),
        (1806, "十八百六"),
        (1807, "十八百七"),
        (1808, "十八百八"),
        (1809, "十八百九"),
        (1810, "十八百十"),
        (1811, "十八百十一"),
        (1812, "十八百十二"),
        (1813, "十八百十三"),
        (1814, "十八百十四"),
        (1815, "十八百十五"),
        (1816, "十八百十六"),
        (1817, "十八百十七"),
        (1818, "十八百十八"),
        (1819, "十八百十九"),
        (1820, "十八百二十"),
        (1821, "十八百二一"),
        (1822, "十八百二二"),
        (1823, "十八百二三"),
        (1824, "十八百二四"),
        (1825, "十八百二五"),
        (1826, "十八百二六"),
        (1827, "十八百二七"),
        (1828, "十八百二八"),
        (1829, "十八百二九"),
        (1830, "十八百三十"),
        (1831, "十八百三一"),
        (1832, "十八百三二"),
        (1833, "十八百三三"),
        (1834, "十八百三四"),
        (1835, "十八百三五"),
        (1836, "十八百三六"),
        (1837, "十八百三七"),
        (1838, "十八百三八"),
        (1839, "十八百三九"),
        (1840, "十八百四十"),
        (1841, "十八百四一"),
        (1842, "十八百四二"),
        (1843, "十八百四三"),
        (1844, "十八百四四"),
        (1845, "十八百四五"),
        (1846, "十八百四六"),
        (1847, "十八百四七"),
        (1848, "十八百四八"),
        (1849, "十八百四九"),
        (1850, "十八百五十"),
        (1851, "十八百五一"),
        (1852, "十八百五二"),
        (1853, "十八百五三"),
        (1854, "十八百五四"),
        (1855, "十八百五五"),
        (1856, "十八百五六"),
        (1857, "十八百五七"),
        (1858, "十八百五八"),
        (1859, "十八百五九"),
        (1860, "十八百六十"),
        (1861, "十八百六一"),
        (1862, "十八百六二"),
        (1863, "十八百六三"),
        (1864, "十八百六四"),
        (1865, "十八百六五"),
        (1866, "十八百六六"),
        (1867, "十八百六七"),
        (1868, "十八百六八"),
        (1869, "十八百六九"),
        (1870, "十八百七十"),
        (1871, "十八百七一"),
        (1872, "十八百七二"),
        (1873, "十八百七三"),
        (1874, "十八百七四"),
        (1875, "十八百七五"),
        (1876, "十八百七六"),
        (1877, "十八百七七"),
        (1878, "十八百七八"),
        (1879, "十八百七九"),
        (1880, "十八百八十"),
        (1881, "十八百八一"),
        (1882, "十八百八二"),
        (1883, "十八百八三"),
        (1884, "十八百八四"),
        (1885, "十八百八五"),
        (1886, "十八百八六"),
        (1887, "十八百八七"),
        (1888, "十八百八八"),
        (1889, "十八百八九"),
        (1890, "十八百九十"),
        (1891, "十八百九一"),
        (1892, "十八百九二"),
        (1893, "十八百九三"),
        (1894, "十八百九四"),
        (1895, "十八百九五"),
        (1896, "十八百九六"),
        (1897, "十八百九七"),
        (1898, "十八百九八"),
        (1899, "十八百九九"),
        (1900, "十九百"),
        (1901, "十九百一"),
        (1902, "十九百二"),
        (1903, "十九百三"),
        (1904, "十九百四"),
        (1905, "十九百五"),
        (1906, "十九百六"),
        (1907, "十九百七"),
        (1908, "十九百八"),
        (1909, "十九百九"),
        (1910, "十九百十"),
        (1911, "十九百十一"),
        (1912, "十九百十二"),
        (1913, "十九百十三"),
        (1914, "十九百十四"),
        (1915, "十九百十五"),
        (1916, "十九百十六"),
        (1917, "十九百十七"),
        (1918, "十九百十八"),
        (1919, "十九百十九"),
        (1920, "十九百二十"),
        (1921, "十九百二一"),
        (1922, "十九百二二"),
        (1923, "十九百二三"),
        (1924, "十九百二四"),
        (1925, "十九百二五"),
        (1926, "十九百二六"),
        (1927, "十九百二七"),
        (1928, "十九百二八"),
        (1929, "十九百二九"),
        (1930, "十九百三十"),
        (1931, "十九百三一"),
        (1932, "十九百三二"),
        (1933, "十九百三三"),
        (1934, "十九百三四"),
        (1935, "十九百三五"),
        (1936, "十九百三六"),
        (1937, "十九百三七"),
        (1938, "十九百三八"),
        (1939, "十九百三九"),
        (1940, "十九百四十"),
        (1941, "十九百四一"),
        (1942, "十九百四二"),
        (1943, "十九百四三"),
        (1944, "十九百四四"),
        (1945, "十九百四五"),
        (1946, "十九百四六"),
        (1947, "十九百四七"),
        (1948, "十九百四八"),
        (1949, "十九百四九"),
        (1950, "十九百五十"),
        (1951, "十九百五一"),
        (1952, "十九百五二"),
        (1953, "十九百五三"),
        (1954, "十九百五四"),
        (1955, "十九百五五"),
        (1956, "十九百五六"),
        (1957, "十九百五七"),
        (1958, "十九百五八"),
        (1959, "十九百五九"),
        (1960, "十九百六十"),
        (1961, "十九百六一"),
        (1962, "十九百六二"),
        (1963, "十九百六三"),
        (1964, "十九百六四"),
        (1965, "十九百六五"),
        (1966, "十九百六六"),
        (1967, "十九百六七"),
        (1968, "十九百六八"),
        (1969, "十九百六九"),
        (1970, "十九百七十"),
        (1971, "十九百七一"),
        (1972, "十九百七二"),
        (1973, "十九百七三"),
        (1974, "十九百七四"),
        (1975, "十九百七五"),
        (1976, "十九百七六"),
        (1977, "十九百七七"),
        (1978, "十九百七八"),
        (1979, "十九百七九"),
        (1980, "十九百八十"),
        (1981, "十九百八一"),
        (1982, "十九百八二"),
        (1983, "十九百八三"),
        (1984, "十九百八四"),
        (1985, "十九百八五"),
        (1986, "十九百八六"),
        (1987, "十九百八七"),
        (1988, "十九百八八"),
        (1989, "十九百八九"),
        (1990, "十九百九十"),
        (1991, "十九百九一"),
        (1992, "十九百九二"),
        (1993, "十九百九三"),
        (1994, "十九百九四"),
        (1995, "十九百九五"),
        (1996, "十九百九六"),
        (1997, "十九百九七"),
        (1998, "十九百九八"),
        (1999, "十九百九九"),
        (2000, "二十百"),
        (2001, "二十百一"),
        (2002, "二十百二"),
        (2003, "二十百三"),
        (2004, "二十百四"),
        (2005, "二十百五"),
        (2006, "二十百六"),
        (2007, "二十百七"),
        (2008, "二十百八"),
        (2009, "二十百九"),
        (2010, "二十百十"),
        (2011, "二十百十一"),
        (2012, "二十百十二"),
        (2013, "二十百十三"),
        (2014, "二十百十四"),
        (2015, "二十百十五"),
        (2016, "二十百十六"),
        (2017, "二十百十七"),
        (2018, "二十百十八"),
        (2019, "二十百十九"),
        (2020, "二十百二十"),
        (2021, "二十百二一"),
        (2022, "二十百二二"),
        (2023, "二十百二三"),
        (2024, "二十百二四"),
        (2025, "二十百二五"),
        (2026, "二十百二六"),
        (2027, "二十百二七"),
        (2028, "二十百二八"),
        (2029, "二十百二九"),
        (2030, "二十百三十"),
        (2031, "二十百三一"),
        (2032, "二十百三二"),
        (2033, "二十百三三"),
        (2034, "二十百三四"),
        (2035, "二十百三五"),
        (2036, "二十百三六"),
        (2037, "二十百三七"),
        (2038, "二十百三八"),
        (2039, "二十百三九"),
        (2040, "二十百四十"),
        (2041, "二十百四一"),
        (2042, "二十百四二"),
        (2043, "二十百四三"),
        (2044, "二十百四四"),
        (2045, "二十百四五"),
        (2046, "二十百四六"),
        (2047, "二十百四七"),
        (2048, "二十百四八"),
        (2049, "二十百四九"),
        (2050, "二十百五十"),
        (2051, "二十百五一"),
        (2052, "二十百五二"),
        (2053, "二十百五三"),
        (2054, "二十百五四"),
        (2055, "二十百五五"),
        (2056, "二十百五六"),
        (2057, "二十百五七"),
        (2058, "二十百五八"),
        (2059, "二十百五九"),
        (2060, "二十百六十"),
        (2061, "二十百六一"),
        (2062, "二十百六二"),
        (2063, "二十百六三"),
        (2064, "二十百六四"),
        (2065, "二十百六五"),
        (2066, "二十百六六"),
        (2067, "二十百六七"),
        (2068, "二十百六八"),
        (2069, "二十百六九"),
        (2070, "二十百七十"),
        (2071, "二十百七一"),
        (2072, "二十百七二"),
        (2073, "二十百七三"),
        (2074, "二十百七四"),
        (2075, "二十百七五"),
        (2076, "二十百七六"),
        (2077, "二十百七七"),
        (2078, "二十百七八"),
        (2079, "二十百七九"),
        (2080, "二十百八十"),
        (2081, "二十百八一"),
        (2082, "二十百八二"),
        (2083, "二十百八三"),
        (2084, "二十百八四"),
        (2085, "二十百八五"),
        (2086, "二十百八六"),
        (2087, "二十百八七"),
        (2088, "二十百八八"),
        (2089, "二十百八九"),
        (2090, "二十百九十"),
        (2091, "二十百九一"),
        (2092, "二十百九二"),
        (2093, "二十百九三"),
        (2094, "二十百九四"),
        (2095, "二十百九五"),
        (2096, "二十百九六"),
        (2097, "二十百九七"),
        (2098, "二十百九八"),
        (2099, "二十百九九"),
        (2100, "二一百"),
        (2101, "二一百一"),
        (2102, "二一百二"),
        (2103, "二一百三"),
        (2104, "二一百四"),
        (2105, "二一百五"),
        (2106, "二一百六"),
        (2107, "二一百七"),
        (2108, "二一百八"),
        (2109, "二一百九"),
        (2110, "二一百十"),
        (2111, "二一百十一"),
        (2112, "二一百十二"),
        (2113, "二一百十三"),
        (2114, "二一百十四"),
        (2115, "二一百十五"),
        (2116, "二一百十六"),
        (2117, "二一百十七"),
        (2118, "二一百十八"),
        (2119, "二一百十九"),
        (2120, "二一百二十"),
        (2121, "二一百二一"),
        (2122, "二一百二二"),
        (2123, "二一百二三"),
        (2124, "二一百二四"),
        (2125, "二一百二五"),
        (2126, "二一百二六"),
        (2127, "二一百二七"),
        (2128, "二一百二八"),
        (2129, "二一百二九"),
        (2130, "二一百三十"),
        (2131, "二一百三一"),
        (2132, "二一百三二"),
        (2133, "二一百三三"),
        (2134, "二一百三四"),
        (2135, "二一百三五"),
        (2136, "二一百三六"),
        (2137, "二一百三七"),
        (2138, "二一百三八"),
        (2139, "二一百三九"),
        (2140, "二一百四十"),
        (2141, "二一百四一"),
        (2142, "二一百四二"),
        (2143, "二一百四三"),
        (2144, "二一百四四"),
        (2145, "二一百四五"),
        (2146, "二一百四六"),
        (2147, "二一百四七"),
        (2148, "二一百四八"),
        (2149, "二一百四九"),
        (2150, "二一百五十"),
        (2151, "二一百五一"),
        (2152, "二一百五二"),
        (2153, "二一百五三"),
        (2154, "二一百五四"),
        (2155, "二一百五五"),
        (2156, "二一百五六"),
        (2157, "二一百五七"),
        (2158, "二一百五八"),
        (2159, "二一百五九"),
        (2160, "二一百六十"),
        (2161, "二一百六一"),
        (2162, "二一百六二"),
        (2163, "二一百六三"),
        (2164, "二一百六四"),
        (2165, "二一百六五"),
        (2166, "二一百六六"),
        (2167, "二一百六七"),
        (2168, "二一百六八"),
        (2169, "二一百六九"),
        (2170, "二一百七十"),
        (2171, "二一百七一"),
        (2172, "二一百七二"),
        (2173, "二一百七三"),
        (2174, "二一百七四"),
        (2175, "二一百七五"),
        (2176, "二一百七六"),
        (2177, "二一百七七"),
        (2178, "二一百七八"),
        (2179, "二一百七九"),
        (2180, "二一百八十"),
        (2181, "二一百八一"),
        (2182, "二一百八二"),
        (2183, "二一百八三"),
        (2184, "二一百八四"),
        (2185, "二一百八五"),
        (2186, "二一百八六"),
        (2187, "二一百八七"),
        (2188, "二一百八八"),
        (2189, "二一百八九"),
        (2190, "二一百九十"),
        (2191, "二一百九一"),
        (2192, "二一百九二"),
        (2193, "二一百九三"),
        (2194, "二一百九四"),
        (2195, "二一百九五"),
        (2196, "二一百九六"),
        (2197, "二一百九七"),
        (2198, "二一百九八"),
        (2199, "二一百九九"),
        (2200, "二二百"),
        (2201, "二二百一"),
        (2202, "二二百二"),
        (2203, "二二百三"),
        (2204, "二二百四"),
        (2205, "二二百五"),
        (2206, "二二百六"),
        (2207, "二二百七"),
        (2208, "二二百八"),
        (2209, "二二百九"),
        (2210, "二二百十"),
        (2211, "二二百十一"),
        (2212, "二二百十二"),
        (2213, "二二百十三"),
        (2214, "二二百十四"),
        (2215, "二二百十五"),
        (2216, "二二百十六"),
        (2217, "二二百十七"),
        (2218, "二二百十八"),
        (2219, "二二百十九"),
        (2220, "二二百二十"),
        (2221, "二二百二一"),
        (2222, "二二百二二"),
        (2223, "二二百二三"),
        (2224, "二二百二四"),
        (2225, "二二百二五"),
        (2226, "二二百二六"),
        (2227, "二二百二七"),
        (2228, "二二百二八"),
        (2229, "二二百二九"),
        (2230, "二二百三十"),
        (2231, "二二百三一"),
        (2232, "二二百三二"),
        (2233, "二二百三三"),
        (2234, "二二百三四"),
        (2235, "二二百三五"),
        (2236, "二二百三六"),
        (2237, "二二百三七"),
        (2238, "二二百三八"),
        (2239, "二二百三九"),
        (2240, "二二百四十"),
        (2241, "二二百四一"),
        (2242, "二二百四二"),
        (2243, "二二百四三"),
        (2244, "二二百四四"),
        (2245, "二二百四五"),
        (2246, "二二百四六"),
        (2247, "二二百四七"),
        (2248, "二二百四八"),
        (2249, "二二百四九"),
        (2250, "二二百五十"),
        (2251, "二二百五一"),
        (2252, "二二百五二"),
        (2253, "二二百五三"),
        (2254, "二二百五四"),
        (2255, "二二百五五"),
        (2256, "二二百五六"),
        (2257, "二二百五七"),
        (2258, "二二百五八"),
        (2259, "二二百五九"),
        (2260, "二二百六十"),
        (2261, "二二百六一"),
        (2262, "二二百六二"),
        (2263, "二二百六三"),
        (2264, "二二百六四"),
        (2265, "二二百六五"),
        (2266, "二二百六六"),
        (2267, "二二百六七"),
        (2268, "二二百六八"),
        (2269, "二二百六九"),
        (2270, "二二百七十"),
        (2271, "二二百七一"),
        (2272, "二二百七二"),
        (2273, "二二百七三"),
        (2274, "二二百七四"),
        (2275, "二二百七五"),
        (2276, "二二百七六"),
        (2277, "二二百七七"),
        (2278, "二二百七八"),
        (2279, "二二百七九"),
        (2280, "二二百八十"),
        (2281, "二二百八一"),
        (2282, "二二百八二"),
        (2283, "二二百八三"),
        (2284, "二二百八四"),
        (2285, "二二百八五"),
        (2286, "二二百八六"),
        (2287, "二二百八七"),
        (2288, "二二百八八"),
        (2289, "二二百八九"),
        (2290, "二二百九十"),
        (2291, "二二百九一"),
        (2292, "二二百九二"),
        (2293, "二二百九三"),
        (2294, "二二百九四"),
        (2295, "二二百九五"),
        (2296, "二二百九六"),
        (2297, "二二百九七"),
        (2298, "二二百九八"),
        (2299, "二二百九九"),
        (2300, "二三百"),
        (2301, "二三百一"),
        (2302, "二三百二"),
        (2303, "二三百三"),
        (2304, "二三百四"),
        (2305, "二三百五"),
        (2306, "二三百六"),
        (2307, "二三百七"),
        (2308, "二三百八"),
        (2309, "二三百九"),
        (2310, "二三百十"),
        (2311, "二三百十一"),
        (2312, "二三百十二"),
        (2313, "二三百十三"),
        (2314, "二三百十四"),
        (2315, "二三百十五"),
        (2316, "二三百十六"),
        (2317, "二三百十七"),
        (2318, "二三百十八"),
        (2319, "二三百十九"),
        (2320, "二三百二十"),
        (2321, "二三百二一"),
        (2322, "二三百二二"),
        (2323, "二三百二三"),
        (2324, "二三百二四"),
        (2325, "二三百二五"),
        (2326, "二三百二六"),
        (2327, "二三百二七"),
        (2328, "二三百二八"),
        (2329, "二三百二九"),
        (2330, "二三百三十"),
        (2331, "二三百三一"),
        (2332, "二三百三二"),
        (2333, "二三百三三"),
        (2334, "二三百三四"),
        (2335, "二三百三五"),
        (2336, "二三百三六"),
        (2337, "二三百三七"),
        (2338, "二三百三八"),
        (2339, "二三百三九"),
        (2340, "二三百四十"),
        (2341, "二三百四一"),
        (2342, "二三百四二"),
        (2343, "二三百四三"),
        (2344, "二三百四四"),
        (2345, "二三百四五"),
        (2346, "二三百四六"),
        (2347, "二三百四七"),
        (2348, "二三百四八"),
        (2349, "二三百四九"),
        (2350, "二三百五十"),
        (2351, "二三百五一"),
        (2352, "二三百五二"),
        (2353, "二三百五三"),
        (2354, "二三百五四"),
        (2355, "二三百五五"),
        (2356, "二三百五六"),
        (2357, "二三百五七"),
        (2358, "二三百五八"),
        (2359, "二三百五九"),
        (2360, "二三百六十"),
        (2361, "二三百六一"),
        (2362, "二三百六二"),
        (2363, "二三百六三"),
        (2364, "二三百六四"),
        (2365, "二三百六五"),
        (2366, "二三百六六"),
        (2367, "二三百六七"),
        (2368, "二三百六八"),
        (2369, "二三百六九"),
        (2370, "二三百七十"),
        (2371, "二三百七一"),
        (2372, "二三百七二"),
        (2373, "二三百七三"),
        (2374, "二三百七四"),
        (2375, "二三百七五"),
        (2376, "二三百七六"),
        (2377, "二三百七七"),
        (2378, "二三百七八"),
        (2379, "二三百七九"),
        (2380, "二三百八十"),
        (2381, "二三百八一"),
        (2382, "二三百八二"),
        (2383, "二三百八三"),
        (2384, "二三百八四"),
        (2385, "二三百八五"),
        (2386, "二三百八六"),
        (2387, "二三百八七"),
        (2388, "二三百八八"),
        (2389, "二三百八九"),
        (2390, "二三百九十"),
        (2391, "二三百九一"),
        (2392, "二三百九二"),
        (2393, "二三百九三"),
        (2394, "二三百九四"),
        (2395, "二三百九五"),
        (2396, "二三百九六"),
        (2397, "二三百九七"),
        (2398, "二三百九八"),
        (2399, "二三百九九"),
        (9900, "九九百"),
        (9901, "九九百一"),
        (9902, "九九百二"),
        (9903, "九九百三"),
        (9904, "九九百四"),
        (9905, "九九百五"),
        (9906, "九九百六"),
        (9907, "九九百七"),
        (9908, "九九百八"),
        (9909, "九九百九"),
        (9910, "九九百十"),
        (9911, "九九百十一"),
        (9912, "九九百十二"),
        (9913, "九九百十三"),
        (9914, "九九百十四"),
        (9915, "九九百十五"),
        (9916, "九九百十六"),
        (9917, "九九百十七"),
        (9918, "九九百十八"),
        (9919, "九九百十九"),
        (9920, "九九百二十"),
        (9921, "九九百二一"),
        (9922, "九九百二二"),
        (9923, "九九百二三"),
        (9924, "九九百二四"),
        (9925, "九九百二五"),
        (9926, "九九百二六"),
        (9927, "九九百二七"),
        (9928, "九九百二八"),
        (9929, "九九百二九"),
        (9930, "九九百三十"),
        (9931, "九九百三一"),
        (9932, "九九百三二"),
        (9933, "九九百三三"),
        (9934, "九九百三四"),
        (9935, "九九百三五"),
        (9936, "九九百三六"),
        (9937, "九九百三七"),
        (9938, "九九百三八"),
        (9939, "九九百三九"),
        (9940, "九九百四十"),
        (9941, "九九百四一"),
        (9942, "九九百四二"),
        (9943, "九九百四三"),
        (9944, "九九百四四"),
        (9945, "九九百四五"),
        (9946, "九九百四六"),
        (9947, "九九百四七"),
        (9948, "九九百四八"),
        (9949, "九九百四九"),
        (9950, "九九百五十"),
        (9951, "九九百五一"),
        (9952, "九九百五二"),
        (9953, "九九百五三"),
        (9954, "九九百五四"),
        (9955, "九九百五五"),
        (9956, "九九百五六"),
        (9957, "九九百五七"),
        (9958, "九九百五八"),
        (9959, "九九百五九"),
        (9960, "九九百六十"),
        (9961, "九九百六一"),
        (9962, "九九百六二"),
        (9963, "九九百六三"),
        (9964, "九九百六四"),
        (9965, "九九百六五"),
        (9966, "九九百六六"),
        (9967, "九九百六七"),
        (9968, "九九百六八"),
        (9969, "九九百六九"),
        (9970, "九九百七十"),
        (9971, "九九百七一"),
        (9972, "九九百七二"),
        (9973, "九九百七三"),
        (9974, "九九百七四"),
        (9975, "九九百七五"),
        (9976, "九九百七六"),
        (9977, "九九百七七"),
        (9978, "九九百七八"),
        (9979, "九九百七九"),
        (9980, "九九百八十"),
        (9981, "九九百八一"),
        (9982, "九九百八二"),
        (9983, "九九百八三"),
        (9984, "九九百八四"),
        (9985, "九九百八五"),
        (9986, "九九百八六"),
        (9987, "九九百八七"),
        (9988, "九九百八八"),
        (9989, "九九百八九"),
        (9990, "九九百九十"),
        (9991, "九九百九一"),
        (9992, "九九百九二"),
        (9993, "九九百九三"),
        (9994, "九九百九四"),
        (9995, "九九百九五"),
        (9996, "九九百九六"),
        (9997, "九九百九七"),
        (9998, "九九百九八"),
        (9999, "九九百九九"),
    ];

    for (num, s) in TEST_CASES.iter() {
        assert_eq!(analyze(&s.chars().collect::<Vec<_>>()), Some(*num))
    }
}
